.. History Store for Data Frames documentation master file, created by
   sphinx-quickstart on Wed May  6 12:09:14 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to History Store for Data Frames's documentation!
=========================================================

.. figure:: ./graphics/logo.png
   :align: center
   :alt: History Store


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   source/readme
   source/documents
   source/serialize


.. _api-ref:

..  toctree::
   :maxdepth: 1
   :caption: API Reference:

   source/api/modules
